#
# spec file for package python-xdis
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-xdis
Version:        4.2.4
Release:        lp152.1.1
Summary:        Python cross-version byte-code disassembler and marshal routines
License:        GPL-2.0-only
URL:            https://github.com/rocky/python-xdis/
Source:         https://github.com/rocky/python-xdis/archive/%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module six >= 1.10.0}
# /SECTION
%python_subpackages

%description
Python cross-version byte-code disassembler and marshal routines.

%prep
%setup -q
# test fails for weird order reasons
rm pytest/test_disasm.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest pytest

%files %{python_files}
%license COPYING
%doc NEWS.md README.rst
%python3_only %{_bindir}/pydisasm
%{python_sitelib}/*

%changelog
* Thu Apr 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.2.4:
  * Add Instruction instance methods: #Instruction.is_jump() and #Instruction.jumps_forward()
* Tue Mar 24 2020 pgajdos@suse.com
- version update to 4.2.3
  * Add Python versions: 3.7.7, 3.8.2, and 3.9.0alpha1,
  * Create a class for "STORE" instructions
  * facilitate code type freezing (PR #57)
  * Warn about cross-decompilation problems for byte types
- deleted patches
  - py382.patch (upstreamed)
* Mon Mar  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to work with 3.8.2:
  * py382.patch
* Thu Feb  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 4.2.2
  * Add Python versions: 3.6.10, 3.7.6. 3.8.1
  * Update 3.9-dev to 3.9.0alpha2
  * Add interpolation of FUNCTION_CALL_{KW,EX} argument for 3.7-3.9
  * Better output of complex type values
  * Correct and clean up compiler flags.
* Tue Dec  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.1.3:
  * Various dependency fixes
* Wed Nov  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.1.2:
  * Python 3.8.0 magic changed
  * More Pypy 3.6 tolerance
  * Fixed DeprecationWarning; thanks to laike9m
* Wed Oct 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.1.1:
  * Fix unmarshaling 3.4+ object_ref bugs. A big thanks to Armin Rigo of the PyPy team.
  * Add Pypy 3.6+ disassembly, e.g. pypy3.6-7.1.0 and pypy3.6-7.1.1
  * Add Python 3.7.5, 2.7.16, 2.7.17rc1, and 2.7.15candidate1 as a valid releases
  * convert unmarshal if .. elif code to a dictionary lookup with function entries
  * Handle newer Python importlib - thanks to laike9m
  * Add early bytecodes: 1.0, 1.1, 1.2, and 1.6. Going off of pycdc bytecode since this is the only bytecode for these versions I know of
  * Fix bug in Python 3.x decompiling 2.x that contains strings with non-ascii characters
  * More generally, better handling of non-ascii Python 2 strings in both input and output in Python 3
  * pypy 3.6-7.1.0 tolerance
* Fri Oct  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.0.4:
  * Add most-recent 3.8 magic number
  * Remove some 3.8 invalid escape warnings
* Mon Aug 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.0.3:
  * Support 3.8.0beta2; Code38 type with posonlyargcount field
  * Add Python versions 3.4.10, 3.7.4 and 3.6.9
  * script no longer works to install pydisasm; entry_points still works
  * Add pypy 3.6 opcode formatting for MAKE_FUNCTION and EXTENDED_ARG
  * Add format_CALL_function and use it or pypy36
  * Start using "blacken" to reformat Python files
* Fri Jun 28 2019 Andreas Färber <afaerber@suse.de>
- Initial (v4.0.2)
